<?php

/*
 * Project: MinecraftLogFileReader
 * File name: online.php
 * Description: Reads the server logfile of Minecraft to provide useful information
 *
 * @original author Michael Csida, Copyright (C) 2011.
 * @auhtor Benjamin Kristensen
 * @version v 0.5.0 2011/09/13
 * @see The GNU Public License (GPL)
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *
 * Changelog:
 *
 * - v0.1.1 - 2011/06/16 - Upload of first working version (Michael Csida)
 * - v0.1.2 - 2011/06/17 - Minor bugfixes and source code layout changes (Benjamin Kristensen)
 * - v0.2.0 - 2011/06/17 - Added Total Play Time and a new layout (online users are on the top of the list and have an earth-background, offline users have a stone-background) (Michael Csida)
 * - v0.2.1 - 2011/06/18 - Minor bugfixes (Benjamin Kristensen)
 * - v0.3.0 - 2011/06/19 - Added option to display all users (not only users on whitelist), added debug-mode, layout changes (Michael Csida)
 *                         Added refresh rate to auto-reload page (Benjamin Kristensen)
 * - v0.3.1 - 2011/06/19 - Speed improvements (Benjamin Kristensen)
 * - v0.4.0 - 2011/08/18 - Added "Play Time per Day" (Michael Csida)
 * - v0.4.1 - 2011/09/02 - Script now ignores empty lines in the white-list. (Michael Csida)
 *                         Fixed a bug where "Play Time per Day" was greater than "Total Play Time" when the user's first login was within the last 24 hours. (Michael Csida)
 * - v0.5.0 - 2011/09/13 - Added an option to sort the list by Name, Total Play Time, Play Time per Day and Status. (Michael Csida)
 *                         Bugfix: Added "banning" and "kicking" to count as logoff/disconnect. Thanks to "TheRayden" from minecraftforum.net for reporting this and for his server logfile! (Michael Csida)
 *                         Date of first login will be displayed when hover over a user's name. (Michael Csida)
 *                         Added a new sky-image and text on top of the list. (Michael Csida)
 */

/*-----------------------------------------------------------------------
--- VARIABLES YOU CAN / NEED TO CHANGE ----------------------------------
-----------------------------------------------------------------------*/

// Necessary:
$path_to_logs = '/home/minecraft/'; 	// Absolute or relative path to the directory where the two files (server logfile and the optionally whitelist) are located
$logfile = 'server.log'; 				// Name of your server logfile

// Optionally:
$use_whitelist = 0;						// Show users on whitelist ONLY? (will be faster) (1 = yes / 0 = no, show all users)
$whitelist = 'white-list.txt'; 			// Name of your server whitelist file (will be ignored if $use_whitelist is 0)
$show_online_first = 1;					// Show online users first when sorting (this is the default setting which can be changed via a dropdown menu) (1 = Show online users first / 0 = Ignore online/offline status for sorting)
$sort_default = 1;						// Default column for sorting (1 = Name, 2 = Total Play Time, 3 = Play Time per Day, 4 = Status) (this is the default setting which can be changed by clicking on a column name)
$display_minute_after = 60; 			// After 60 seconds (default), minutes will be displayed instead of seconds (only for the "Status" column)
$display_hour_after = 7200; 			// After 7200 seconds (120 minutes) (default), hours will be displayd instead of minutes (only for the "Status" column)
$display_day_after = 172800; 			// After 172800 seconds (48 hours) (default), days will be displayed instead of hours (only for the "Status" column)
$remove_offline_after = 2592000;		// After 2592000 seconds (30 days) (default) offline, the users will not be shown in the list
$refresh_rate = 60;						// After 60 seconds (default), the page auto-reloads to update the values (set to 0 to disable auto-reload)
$debug = 1;								// To display debug information at the end of the page (1 = yes / 0 = no)

/*-----------------------------------------------------------------------
--- CODE (DO NOT CHANGE ANYTHING) ---------------------------------------
-----------------------------------------------------------------------*/

// Sort - function for multidimensional arrays (from http://www.php.net/manual/en/function.sort.php#104464)
function sortmulti ($array, $index, $order, $natsort, $case_sensitive) {
	if(is_array($array) && count($array)>0) {
		foreach(array_keys($array) as $key)
			$temp[$key]=$array[$key][$index];
		if(!$natsort) {
			if ($order=='asc')
				asort($temp);
			else
				arsort($temp);
		} else {
			if ($case_sensitive==true)
				natsort($temp);
			else
				natcasesort($temp);
			if($order!='asc')
				$temp=array_reverse($temp,TRUE);
		}
		foreach(array_keys($temp) as $key)
			if (is_numeric($key))
				$sorted[]=$array[$key];
			else
				$sorted[$key]=$array[$key];
		return $sorted;
	}
	return $sorted;
}


// To calculate total runtime of the script
function getmicrotime(){
	list($usec, $sec) = explode(" ",microtime());
	return ((float)$usec + (float)$sec);
}

if ($debug == 1) {
	$time_start = getmicrotime();
}


// Fill variables
$file_logfile = $path_to_logs.$logfile;
$array_logfile = file($file_logfile);
date_default_timezone_set(@date_default_timezone_get());
$current_time = time();
$current_filename = basename($_SERVER['PHP_SELF']);
if ($use_whitelist == 1) {
	$file_whitelist = $path_to_logs.$whitelist;
	$array_whitelist = file($file_whitelist);
}


// Temporary LogFile Array with Online/Offline - Info rows only
$h = 0;
foreach($array_logfile as $log_line) {
	if(preg_match('@lost connection: disconnect\.|: Banning|: Kicking|logged in with entity id@', $log_line)) {
		$array_logfile_temp_onoff[$h] = $log_line;
		$h++;
	}
}


// Create array for username, current userstatus, last change of online/offline status, total play time, play time per day and first login
$h = 0;
if ($use_whitelist == 1) {
	for ($i = 0; $i < count($array_whitelist); $i++) {
		if (rtrim(ltrim($array_whitelist[$i])) != "") {
			$array_users[$h]['name'] = rtrim(ltrim($array_whitelist[$i]));
			$array_users[$h]['status'] = 'UNCLEAR';
			$array_users[$h]['lastchange'] = 0;
			$array_users[$h]['totaltime'] = 0;
			$array_users[$h]['hoursperday'] = 0;
			$array_users[$h]['firstlogin'] = 0;
			$h++;
		}		
	}
} else {
	$array_users_temp = array();
	$h = 0;
	for ($i = 0; $i < count($array_logfile_temp_onoff); $i++) {
		if (preg_match('#logged in with entity id#', $array_logfile_temp_onoff[$i])) {
			$array_help1 = explode(" [INFO] ", $array_logfile_temp_onoff[$i]);
			$array_help2 = explode(" ", $array_help1[1], 2);
			$flipped_array = array_flip($array_users_temp); 
			if (!isset($flipped_array[$array_help2[0]])) { 
				$array_users_temp[$h] = $array_help2[0];
				$h++; 
			}
		}
	}
	for ($i = 0; $i < count($array_users_temp); $i++) {
		$array_users[$i]['name'] = $array_users_temp[$i];
		$array_users[$i]['status'] = 'UNCLEAR';
		$array_users[$i]['lastchange'] = 0;
		$array_users[$i]['totaltime'] = 0;
		$array_users[$i]['hoursperday'] = 0;
		$array_users[$i]['firstlogin'] = 0;
	}
}
$count_user = count($array_users);


// Script: Finding out Online/Offline - Status and set timestamp of last change
$users_checked = 0;
$lines_to_check = count($array_logfile_temp_onoff) - 1;

while (($users_checked < $count_user) && ($lines_to_check >= 0)) {
	$array_temp1 = explode(" [INFO] ", $array_logfile_temp_onoff[$lines_to_check]);
	$array_temp2 = explode(" ", $array_temp1[1], 2);
	$user_to_check = $array_temp2[0];
	if (preg_match('#: Banning#', $array_temp1[1])) {
		$array_temp_bankick = explode(": Banning ", $array_temp1[1], 2);
		$user_to_check = rtrim(ltrim($array_temp_bankick[1]));
	}
	if (preg_match('#: Kicking#', $array_temp1[1])) {
		$array_temp_bankick = explode(": Kicking ", $array_temp1[1], 2);
		$user_to_check = rtrim(ltrim($array_temp_bankick[1]));
	}
	for ($i = 0; $i < $count_user; $i++) {
		if ((strtoupper($array_users[$i]['name']) == strtoupper($user_to_check)) && $array_users[$i]['status'] == 'UNCLEAR') {
			if (preg_match('@: Banning|: Kicking@', $array_temp1[1])) $array_users[$i]['status'] = 'OFFLINE';
			if (preg_match('#lost connection: disconnect.#', $array_temp2[1])) $array_users[$i]['status'] = 'OFFLINE';
			if (preg_match('#logged in with entity id#', $array_temp2[1])) $array_users[$i]['status'] = 'ONLINE';
			$array_temp3 = explode(" ", $array_temp1[0]);
			$array_temp4 = explode("-", $array_temp3[0]);
			$array_temp5 = explode(":", $array_temp3[1]);
			$array_users[$i]['lastchange'] = mktime($array_temp5[0],$array_temp5[1],$array_temp5[2],$array_temp4[1],$array_temp4[2],$array_temp4[0]);
			$array_users[$i]['name'] = $user_to_check;
			$users_checked++;
		}
	}
	$lines_to_check--;
}


// Script: Finding out Total Play Time
$array_logline_timestamp = array();
$array_logline_user = array();
$array_logline_status = array();

for ($i = 0; $i < $count_user; $i++) { // Check one user after another
	$f = 0;
	unset($array_logfile_temp_user);
	for ($g = 0; $g < count($array_logfile_temp_onoff); $g++) { // Create array for online/offline information for this user only
		$array_temp6 = explode(" [INFO] ", $array_logfile_temp_onoff[$g]);
		$array_temp7 = explode(" ", $array_temp6[1], 2);
		$user_to_check = $array_temp7[0];
		if (preg_match('#: Banning#', $array_temp6[1])) {
			$array_temp_bankick = explode(": Banning ", $array_temp6[1], 2);
			$user_to_check = rtrim(ltrim($array_temp_bankick[1]));
		}
		if (preg_match('#: Kicking#', $array_temp6[1])) {
			$array_temp_bankick = explode(": Kicking ", $array_temp6[1], 2);
			$user_to_check = rtrim(ltrim($array_temp_bankick[1]));
		}
		if (strtoupper($array_users[$i]['name']) == strtoupper($user_to_check)) {
			$array_logfile_temp_user[$f] = $array_logfile_temp_onoff[$g];
			$f++;
		}
	}
	for ($e = 0; $e < count($array_logfile_temp_user); $e++) { // Store all the loglines of the user-array to other arrays once
		$array_logline_temp1 = explode(" [INFO] ", $array_logfile_temp_user[$e]);
		$array_logline_temp2 = explode(" ", $array_logline_temp1[0]);
		$array_logline_temp3 = explode("-", $array_logline_temp2[0]);
		$array_logline_temp4 = explode(":", $array_logline_temp2[1]);
		$array_logline_temp5 = explode(" ", $array_logline_temp1[1], 2);

		$array_logline_timestamp[$e] = mktime($array_logline_temp4[0],$array_logline_temp4[1],$array_logline_temp4[2],$array_logline_temp3[1],$array_logline_temp3[2],$array_logline_temp3[0]);
		
		if (preg_match('@: Banning|: Kicking@', $array_logline_temp1[1])) {
			if (preg_match('#: Banning#', $array_logline_temp1[1])) {
				$array_temp_bankick = explode(": Banning ", $array_temp1[1], 2);
			}
			if (preg_match('#: Kicking#', $array_logline_temp1[1])) {
				$array_temp_bankick = explode(": Kicking ", $array_temp1[1], 2);
			}
			$array_logline_user[$e] = rtrim(ltrim($array_temp_bankick[1]));
			$array_logline_status[$e] = 'OFFLINE';
		}
		if (preg_match('#logged in with entity id#', $array_logline_temp5[1])) {
			$array_logline_status[$e] = 'ONLINE';
			$array_logline_user[$e] = $array_logline_temp5[0];
			}
		if (preg_match('#lost connection: disconnect.#', $array_logline_temp5[1])) {
			$array_logline_status[$e] = 'OFFLINE';
			$array_logline_user[$e] = $array_logline_temp5[0];
		}
	}
	for ($h = 0; $h < count($array_logfile_temp_user); $h++) { // Calculating Total Played Time
		if ($h == 0) { // First entry of the user logfile
			$temp_current_timestamp = $array_logline_timestamp[$h];
			$array_users[$i]['firstlogin'] = $array_logline_timestamp[$h]; // For "hours per day"
		} else if (($h > 0) && ($h < count($array_logfile_temp_user)-1)){
			if (($array_logline_status[$h] == 'ONLINE') && ($array_logline_status[$h-1] == 'OFFLINE')) {
				$temp_current_timestamp = $array_logline_timestamp[$h];
			}
			if (($array_logline_status[$h] == 'OFFLINE') && ($array_logline_status[$h-1] == 'ONLINE')) {
				$diff = $array_logline_timestamp[$h] - $temp_current_timestamp;
				$array_users[$i]['totaltime'] = $array_users[$i]['totaltime'] + $diff;
			}
		} else if ($h == count($array_logfile_temp_user)-1) { // Last entry of the user logfile
			if ($array_logline_status[$h] == 'ONLINE') {
				$diff = $current_time - $array_logline_timestamp[$h];
				$array_users[$i]['totaltime'] = $array_users[$i]['totaltime'] + $diff;
			}
			if ($array_logline_status[$h] == 'OFFLINE') {
				$diff = $array_logline_timestamp[$h] - $temp_current_timestamp;
				$array_users[$i]['totaltime'] = $array_users[$i]['totaltime'] + $diff;
			}
		}
	}
}

// Calculating hours per day
for ($i = 0; $i < $count_user; $i++) {
	$active_days = ($current_time - $array_users[$i]['firstlogin']) / 60 / 60 / 24;
	$array_users[$i]['hoursperday'] = round(($array_users[$i]['totaltime'] /60 / 60 / $active_days), 3);
}


// Sort user array
if (!isset($_GET['sort_by'])) {
	switch($sort_default) {
		case 1: $_GET['sort_by'] = 'name'; $_GET['sort_order'] = 'asc'; break;
		case 2: $_GET['sort_by'] = 'totaltime'; $_GET['sort_order'] = 'desc'; break;
		case 3: $_GET['sort_by'] = 'hoursperday'; $_GET['sort_order'] = 'desc'; break;
		case 4: $_GET['sort_by'] = 'lastchange'; $_GET['sort_order'] = 'desc'; break;
	}
}

if (!isset($_GET['show_online_first'])) {
	$_GET['show_online_first'] = $show_online_first;
}

if ($_GET['show_online_first'] == 1) { // Online users first
	if ($_GET['sort_by'] == 'name') {
		$temp_array_users_sorted = sortmulti($array_users, $_GET['sort_by'], $_GET['sort_order'], TRUE, FALSE);
	} else {
		$temp_array_users_sorted = sortmulti($array_users, $_GET['sort_by'], $_GET['sort_order'], FALSE, FALSE);	
	}
	$h=0;
	for ($i = 0; $i < $count_user; $i++) {
		if ($temp_array_users_sorted[$i]['status'] == 'ONLINE') {
			$array_users_sorted[$h]['name'] = $temp_array_users_sorted[$i]['name'];
			$array_users_sorted[$h]['status'] = $temp_array_users_sorted[$i]['status'];
			$array_users_sorted[$h]['lastchange'] = $temp_array_users_sorted[$i]['lastchange'];
			$array_users_sorted[$h]['totaltime'] = $temp_array_users_sorted[$i]['totaltime'];
			$array_users_sorted[$h]['hoursperday'] = $temp_array_users_sorted[$i]['hoursperday'];
			$array_users_sorted[$h]['firstlogin'] = $temp_array_users_sorted[$i]['firstlogin'];
			$h++;
		}
	}
	for ($i = 0; $i < $count_user; $i++) {
		if ($temp_array_users_sorted[$i]['status'] != 'ONLINE') {
			$array_users_sorted[$h]['name'] = $temp_array_users_sorted[$i]['name'];
			$array_users_sorted[$h]['status'] = $temp_array_users_sorted[$i]['status'];
			$array_users_sorted[$h]['lastchange'] = $temp_array_users_sorted[$i]['lastchange'];
			$array_users_sorted[$h]['totaltime'] = $temp_array_users_sorted[$i]['totaltime'];
			$array_users_sorted[$h]['hoursperday'] = $temp_array_users_sorted[$i]['hoursperday'];
			$array_users_sorted[$h]['firstlogin'] = $temp_array_users_sorted[$i]['firstlogin'];
			$h++;
		}
	}
} else { // Ignore online/offline status for sorting
	if ($_GET['sort_by'] == 'name') {
		$array_users_sorted = sortmulti($array_users, $_GET['sort_by'], $_GET['sort_order'], TRUE, FALSE);
	} else {
		$array_users_sorted = sortmulti($array_users, $_GET['sort_by'], $_GET['sort_order'], FALSE, FALSE);
	}
}
?>


<!-----------------------------------------------------------------------
--- OUTPUT --------------------------------------------------------------
------------------------------------------------------------------------>

<html>

<body background="pictures/background.png">

<head>
	<link rel=stylesheet type="text/css" href="style.css">
	<?php if ($refresh_rate > 0) echo "<meta http-equiv=\"refresh\" content=\"".$refresh_rate."\">"; ?>
</head>

</body>

<br><br>

<table width=825 align="center" cellpadding=3 cellspacing=3 border=0>
	<tr style="background: url(pictures/sky.png); height:100px;">
	<td colspan=5 height=100><center><span class="shadow">MinecraftLogFileReader</span><br><span class="shadow_small">v0.5.0</span></center></td>
	</tr>
	<tr style="background: url(pictures/table_background_01.png); height:35px;">
		<td width=25>&nbsp;</td>
		<td width=125 style="vertical-align: bottom;"><center><a class="togreen" href="<?php echo $current_filename; ?>?sort_by=name&sort_order=asc&show_online_first=<?php echo $_GET['show_online_first'];?>">Name</a></center></td>
		<td width=225 style="vertical-align: bottom;"><center><a class="togreen" href="<?php echo $current_filename; ?>?sort_by=totaltime&sort_order=desc&show_online_first=<?php echo $_GET['show_online_first'];?>">Total Play Time</a></center></td>
		<td width=225 style="vertical-align: bottom;"><center><a class="togreen" href="<?php echo $current_filename; ?>?sort_by=hoursperday&sort_order=desc&show_online_first=<?php echo $_GET['show_online_first'];?>">Play Time per Day</a></center></td>
		<td width=225 style="vertical-align: bottom;"><center><a class="togreen" href="<?php echo $current_filename; ?>?sort_by=lastchange&sort_order=desc&show_online_first=<?php echo $_GET['show_online_first'];?>">Status</a></center></td>
	</tr>
	<?php
	$count_user_displayed = 0;
	for ($i = 0; $i < $count_user; $i++) {
		if (($current_time - $array_users_sorted[$i]['lastchange'] < $remove_offline_after) || ($array_users_sorted[$i]['status'] == 'ONLINE')) {
			echo "\n<tr style=\"background: url(pictures/";
			if ($array_users_sorted[$i]['status'] == 'ONLINE') echo "table_background_02.png";
			else echo "table_background_03.png";
			echo ")\">\n<td><center><img src=\"pictures/";
			if ($array_users_sorted[$i]['status'] == 'ONLINE') echo "online";
			else if ($array_users_sorted[$i]['status'] == 'OFFLINE') echo "offline";
			else echo "unclear";
			echo ".jpg\"></center></td>\n";
			$temp_totaltime_minutes = sprintf("%01.1f", round($array_users_sorted[$i]['totaltime']/60, 1));
			$temp_totaltime_hours = sprintf("%01.1f", round($array_users_sorted[$i]['totaltime']/60/60, 1));
			$temp_totaltime_days = sprintf("%01.2f", round($array_users_sorted[$i]['totaltime']/60/60/24, 2));
			$temp_firstlogin = date("Y-m-d",$array_users_sorted[$i]['firstlogin']);
			echo "<td><center><div class=\"ToolText\" onMouseOver=\"javascript:this.className='ToolTextHover'\" onMouseOut=\"javascript:this.className='ToolText'\">".$array_users_sorted[$i]['name']."<span>First Login: ".$temp_firstlogin."</span></div></center></td>\n";
			echo "<td><center><span class=\"vnn10white\">".$temp_totaltime_hours." hours (".$temp_totaltime_days." days)</center></td>";
			$output_hours = sprintf("%01.2f", round($array_users_sorted[$i]['hoursperday'], 2));
			$output_minutes = sprintf("%01.1f", round(($array_users_sorted[$i]['hoursperday'] * 60), 1));
			if ($output_minutes > $temp_totaltime_minutes) {
				echo "<td><center><span class=\"vnn10white\">".$temp_totaltime_minutes." minutes (".$temp_totaltime_hours." hours)</span></center></td>\n";
			} else {
				echo "<td><center><span class=\"vnn10white\">".$output_minutes." minutes (".$output_hours." hours)</span></center></td>\n";
			}
			echo "<td><span class=\"vnn10white\">";
			if ($array_users_sorted[$i]['status'] == 'ONLINE') echo "Online for ";
			else if ($array_users_sorted[$i]['status'] == 'OFFLINE') echo "Last online: ";
			else echo "Unclear";
			$diff = $current_time - $array_users_sorted[$i]['lastchange'];
			if ($array_users_sorted[$i]['lastchange'] == 0) {
				echo "";
			} else if ($diff >= $display_day_after) {
				$temp = floor($diff/86400);
				echo $temp." day"; if ($temp > 1) echo "s";
			} else if ($diff >= $display_hour_after) {
				$temp = floor($diff/3600);
				echo $temp." hour"; if ($temp > 1) echo "s";
			} else if ($diff >= $display_minute_after) {
				$temp = floor($diff/60);
				echo $temp." minute"; if ($temp > 1) echo "s";
			} else {
				echo $diff." second"; if ($diff > 1) echo "s";
			}
			if ($array_users_sorted[$i]['status'] == 'OFFLINE') echo " ago";		
			echo "</span></td>\n";
			echo "</tr>\n";
			$count_user_displayed++;
		}
	}
	echo "<tr style=\"background: url(pictures/table_background_03.png)\"><td colspan=5 style=\"padding:15px; text-align:center; vertical-align:center;\">";
	echo "<form name=\"form\" action=\"".$current_filename."\" method=\"GET\" style=\"display:inline;\">";
	echo "<span class=\"vnn10white\">List is currently sorted by \"";
	switch ($_GET['sort_by']) {
		case 'name': echo "Name"; break;
		case 'totaltime': echo "Total Play Time"; break;
		case 'hoursperday': echo "Play Time per Day"; break;
		case 'lastchange': echo "Status (last change)"; break;
	}
	echo "\" || When sorting: </span>\n";
	echo "<input type=\"hidden\" name=\"sort_by\" value=\"".$_GET['sort_by']."\">\n";
	echo "<input type=\"hidden\" name=\"sort_order\" value=\"".$_GET['sort_order']."\">\n";
	echo "<select name=\"show_online_first\" onChange=\"submit()\">\n";
	echo "<option value=1";	if ($_GET['show_online_first'] == 1) echo " selected"; echo ">Show online users first</option>\n";
	echo "<option value=0";	if ($_GET['show_online_first'] == 0) echo " selected"; echo ">Ignore online/offline status</option>\n";
	echo "</select></form></td></tr>\n";
	if ($debug == 1) {
		$time_end = getmicrotime();
		$time = round($time_end - $time_start,4);
		$lines_read = count($array_logfile_temp_onoff) - $lines_to_check - 1;
		$remove_offline_days = sprintf("%01.2f", round($remove_offline_after/60/60/24, 2));
		$logfile_size = sprintf("%01.2f", round(filesize("$file_logfile")/1000000, 2));
		echo "<tr style=\"background: url(pictures/table_background_03.png)\">";
		echo "<td colspan=5 style=\"padding:10px; vertical-align:center;\"><span class=\"vnn10white\">Page was generated in ".$time." seconds.<br>";
		echo "Users found in "; if ($use_whitelist == 1) echo "whitelist"; else echo "logfile"; echo ": ".$count_user."<br>";
		echo "Users displayed: ".$count_user_displayed." (showing only users who are not offline for more than ".sprintf("%01.2f", round($remove_offline_after/60/60/24, 2))." days)<br>";
		echo "Total logfile lines: ".count($array_logfile)." (logfile size: ".$logfile_size."MB)<br>";
		echo "Logfile lines with online/offline information: ".count($array_logfile_temp_onoff)."<br>";
		echo "Logfile lines read to find out online/offline status: ".$lines_read."</span></td>";
		echo "</tr>";
	}
	?>
</table>

<br><br>

</html>